bayespy.nodes.VaryingGaussianMarkovChain.initialize_from_prior
==============================================================

.. currentmodule:: bayespy.nodes

.. automethod:: VaryingGaussianMarkovChain.initialize_from_prior